@@ -68,6 +68,7 @@ def integrand_cyl(u, R, z,
     """
     Compute all the non-zero JAM first and second intrinsic velocity moments
     using the formulas from Cappellari (2008, MNRAS, 390, 71; hereafter C08).
+    https://ui.adsabs.harvard.edu/abs/2008MNRAS.390...71C
 
     """
     bani = 1./(1. - beta[:, None, None])  # Anisotropy ratio b = (sig_R/sig_z)**2
@@ -137,7 +138,8 @@ def integand_tan_dth_pot(u, r, th, dens_pot, sigma_pot, qintr_pot):
     """
     Returns the integrand of the tan(th)*d(pot)/dth derivative
     of the MGE potential at (r, th).
-    This is equation (51) of Cappellari (2020, MNRAS, arXiv:1907.09894)
+    This is equation (51) of Cappellari (2020, MNRAS, 494, 4819)
+    https://ui.adsabs.harvard.edu/abs/2020MNRAS.494.4819C
 
     """
     # DE change of variables for Chandrasekhar u-integral [-3,3] -> [0,inf]
@@ -160,7 +162,8 @@ def integrand_sph(s, t, r, th, dens_lum, sigma_lum, qintr_lum,
                   dens_pot, sigma_pot, qintr_pot, beta, gamma, component):
     """
     Solution of the spherically-aligned Jeans equations for an MGE
-    from eq.(52)-(54) of Cappellari (2020, MNRAS, arXiv:1907.09894)
+    from eq.(52)-(54) of Cappellari (2020, MNRAS, 494, 4819)
+    https://ui.adsabs.harvard.edu/abs/2020MNRAS.494.4819C
 
     """
     dens_lum = dens_lum[:, None, None]
@@ -369,7 +372,7 @@ class jam_axi_intr:
       `Cappellari (2008) <https://ui.adsabs.harvard.edu/abs/2008MNRAS.390...71C>`_
 
     - The spherically-aligned ``(r, th, phi)`` solution was presented in
-      `Cappellari (2020) <https://ui.adsabs.harvard.edu/abs/10.1093/mnras/staa959>`_
+      `Cappellari (2020) <https://ui.adsabs.harvard.edu/abs/2020MNRAS.494.4819C>`_
 
     Calling Sequence
     ----------------
@@ -395,20 +398,20 @@ class jam_axi_intr:
         the intrinsic density of the tracer population for which the kinematics
         is derived.
         The units are arbitarary as they cancel out in the final results.
-        Typical units are e.g. Lsun/pc^3 (solar luminosities per parsec^3)
+        Typical units are e.g. ``Lsun/pc^3`` (solar luminosities per ``parsec^3``)
     sigma_lum: array_like with shape (n,)
-        vector containing the dispersion (sigma) in pc of the MGE
+        vector containing the dispersion (sigma) in ``pc`` of the MGE
         Gaussians describing the galaxy kinematic-tracer population.
     qintr_lum: array_like with shape (n,)
         vector containing the intrinsic axial ratio (q) of the MGE
         Gaussians describing the galaxy kinematic-tracer population.
     surf_pot: array_like with shape (m,)
         vector containing the peak value of the MGE Gaussians
-        describing the galaxy total-mass density in units of Msun/pc^3 (solar
-        masses per parsec^3). This is the MGE model from which the model
-        gravitational potential is computed.
+        describing the galaxy total-mass density in units of ``Msun/pc^3``
+        (solar masses per ``parsec^3``). This is the MGE model from which the
+        model gravitational potential is computed.
     sigma_pot: array_like with shape (m,)
-        vector containing the dispersion in pc of the MGE
+        vector containing the dispersion in ``pc`` of the MGE
         Gaussians describing the galaxy total-mass density.
     qintr_pot: array_like with shape (m,)
         vector containing the intrinsic axial ratio of the MGE
@@ -416,14 +419,14 @@ class jam_axi_intr:
     mbh: scalar
         Mass of a nuclear supermassive black hole in solar masses.
     Rbin: array_like with shape (p,)
-        Vector with the ``R`` coordinates in pc of the bins (or pixels) at
+        Vector with the ``R`` coordinates in ``pc`` of the bins (or pixels) at
         which one wants to compute the model predictions. This is the first
         cylindrical coordinate ``(R, z)`` with the galaxy center at ``(0,0)``.
 
-        There is a singularity at ``(0,0)`` which should be avoided by the user
+        There is a singularity at ``(0, 0)`` which should be avoided by the user
         in the input coordinates.
     zbin: array_like with shape (p,)
-        Vector with the ``z`` coordinates in pc of the bins (or pixels) at
+        Vector with the ``z`` coordinates in ``pc`` of the bins (or pixels) at
         which one wants to compute the model predictions. This is the second
         cylindrical coordinate ``(R, z)``, with the z-axis coincident with the
         galaxy symmetry axis.
@@ -432,7 +435,7 @@ class jam_axi_intr:
     -----------------
 
     beta: array_like with shape (n,)
-        Vector with the vertical anisotropy of the individual kinematic-tracer
+        Vector with the axial anisotropy of the individual kinematic-tracer
         MGE Gaussians (Default: ``beta=np.zeros(n)``)::
 
             beta = 1 - (sigma_th/sigma_r)^2  # with align=`sph`
@@ -441,13 +444,20 @@ class jam_axi_intr:
     data: array_like of shape (4, p)
         Four input vectors with the observed values of:
 
-        - ``[sigR, sigz, sigphi, vphi]`` in km/s, when ``align='cyl'``
+        - ``[sigR, sigz, sigphi, vrms_phi]`` in ``km/s``, when ``align='cyl'``
           (or ``align='sph'`` and ``proj_cyl=True``).
 
-        - ``[sigr, sigth, sigphi, vphi]`` in km/s, when ``align='sph'``.
+          ``vrms_phi`` is the square root of the velocity second moment in the
+          tangential direction. If the velocities ``vphi_j`` are measured from
+          individual stars then ``vrms_phi = sqrt(mean(vphi_j^2))``.
+          One also has the relation ``vrms_phi = sqrt(vphi^2 + sigphi^2)``,
+          where ``vphi = mean(vphi_j)`` and ``sigphi = std(vphi_j)``
+
+        - ``[sigr, sigth, sigphi, vrms_phi]`` in ``km/s``, when ``align='sph'``,
+          where ``vrms_phi`` is defined above.
 
     errors: array_like of shape (4, p)
-        errors on ``data``, in the same format (default 5 km/s).
+        ``1sigma`` uncertainties on ``data``, in the same format (default 5 ``km/s``).
     gamma: array_like with shape (n,)
         Vector with the tangential anisotropy of the individual kinematic-tracer
         MGE Gaussians (Default: ``gamma=np.zeros(n)``)::
@@ -468,10 +478,10 @@ class jam_axi_intr:
         the same data with both modelling assumptions.
     rbh: float, optional
         This scalar gives the sigma in arcsec of the Gaussian representing the
-        central black hole of mass MBH [See Section 3.1.2 of `Cappellari (2008)`_].
+        central black hole of mass ``mbh`` [See Section 3.1.2 of `Cappellari (2008)`_].
         The gravitational potential is indistinguishable from a point source
-        for radii > 2*RBH, so the default RBH=0.01 arcsec is appropriate in
-        most current situations.
+        for ``radii > 2*rbh``, so the default ``rbh=0.01`` arcsec is appropriate for
+        observations taken with most current telescopes.
 
         ``rbh`` should not be decreased unless actually needed!
 
@@ -504,15 +514,19 @@ class jam_axi_intr:
             tangential ``phi`` direction at each ``(R, z)`` location.
 
         The mean velocity can be computed as ``vphi = np.sqrt(v2phi - sig2phi)``
+
+        NOTE: I return squared velocities instead of taking the square root, 
+        to allow for negative values.
     .flux: array_like  with shape (p,)
         Vector with the MGE luminosity density at each ``(R, z)`` location in
         ``Lsun/pc^3``, used to plot the isophotes on the model results.
     .ml: float
-        Best fitting M/L.
+        Best fitting M/L. This value is fitted ignoring ``sigphi`` and it is
+        strictly independent of the adopted tangential anisotropy ``gamma``.
     .chi2: float
         Reduced chi^2 (chi^2/DOF) describing the quality of the fit::
 
-            chi^2 = np.sum(((data[goodbins] - model[goodbins])/errors[goodbins])^2)
+            chi2 = np.sum(((data[goodbins] - model[goodbins])/errors[goodbins])**2)
                   / goodbins.sum()
 
     ###########################################################################
@@ -555,7 +569,7 @@ class jam_axi_intr:
         # The error increases to 14% at 1*sigmaBH, independently of the BH mass.
         #
         if mbh > 0:
-            sigmaBH = rbh # Adopt for the BH just a very small size of (default 1pc)
+            sigmaBH = rbh # Adopt for the BH just a very small size (default 1pc)
             dens_bh = mbh/(np.sqrt(2*np.pi)*sigmaBH)**3
             dens_pot = np.append(dens_bh, dens_pot) # Add Gaussian to potential only!
             sigma_pot = np.append(sigmaBH, sigma_pot)
@@ -563,6 +577,7 @@ class jam_axi_intr:
 
         t = clock()
 
+        # Models contain [sig2r, sig2th, sig2phi, v2phi]
         *model, nu = intrinsic_moments(
             Rbin, zbin, dens_lum, sigma_lum, qintr_lum,
             dens_pot, sigma_pot, qintr_pot, beta, gamma, nrad, nang, epsrel,
@@ -574,26 +589,29 @@ class jam_axi_intr:
         if data is None:
 
             chi2 = None
-            if (ml is None) or (ml == 1):
+            if ml is None:
                 ml = 1.
 
         else:
 
-            model1 = copy.deepcopy(model)   # For plotting (sig2r, sig2th, sig2phi, v2phi)
-            model1[3] -= model[2]           # Vphi2 = V2phi - sig2phi
-            model1 = np.sqrt(model1)
-            d, m, e, ok = map(np.concatenate, [data, model1, errors, goodbins])
+            model0 = np.sqrt(np.clip(model, 0, None))   # sqrt([sig2r, sig2th, sig2phi, v2phi])
 
+            # Exclude sigphi from M/L calculation
             if (ml is None) or (ml <= 0):
-                # eq. (51) of Cappellari (2008, MNRAS)
-                ml = (np.sum(d[ok]*m[ok]/e[ok]**2)/np.sum((m[ok]/e[ok])**2))**2
-                m *= np.sqrt(ml)
-                model1 = m.reshape(4, -1)
+                m = np.delete(model0, 2, 0).ravel()     # sqrt([sig2r, sig2th, v2phi])
+                d = np.delete(data, 2, 0).ravel()
+                e = np.delete(errors, 2, 0).ravel()
+                ok = np.delete(goodbins, 2, 0).ravel()
+                d, m = (d/e)[ok], (m/e)[ok]
+                ml = ((d @ m)/(m @ m))**2   # eq. (51) of Cappellari (2008, MNRAS)
 
+            # Use full data for chi2 calculation
+            model0 *= np.sqrt(ml)
+            d, m, e, ok = map(np.ravel, [data, model0, errors, goodbins])
             chi2 = np.sum(((d[ok] - m[ok])/e[ok])**2)/ok.sum()
 
             if plot:
-                self.plot_jam(Rbin, zbin, data, model1, nu,
+                self.plot_jam(Rbin, zbin, data, model0, nu,
                               nodots=nodots, fignum=fignum, align=align)
 
         self.model = np.array(model)*ml   # model ~ V^2
@@ -610,12 +628,12 @@ class jam_axi_intr:
         fig.subplots_adjust(hspace=0.03)
 
         if align == 'cyl':
-            txt = [r"$\sigma_R$", r"$\sigma_z$", r"$\sigma_\phi$", r"$V_\phi$"]
+            txt = [r"$\sigma_R$", r"$\sigma_z$", r"$\sigma_\phi$", r"$V^{\rm rms}_\phi$"]
         else:
-            txt = [r"$\sigma_r$", r"$\sigma_\theta$", r"$\sigma_\phi$", r"$V_\phi$"]
+            txt = [r"$\sigma_r$", r"$\sigma_\theta$", r"$\sigma_\phi$", r"$V^{\rm rms}_\phi$"]
 
         ax[0, 0].set_title("Data")
-        ax[0, 1].set_title("JAM Model")
+        ax[0, 1].set_title(f"JAM$_{{\\rm {align}}}$ Model")
 
         for j, (d, m, t) in enumerate(zip(data, model, txt)):
             plt.sca(ax[j, 0])
