@@ -43,7 +43,10 @@ def vmom_proj(x1, y1, inc,
     """
     This routine gives the projected first velocity moments
     and the second velocity moments tensor for a JAM model with
-    spherically-aligned velocity ellipsoid from Cappellari (2020, hereafter C20)
+    either cylindrically or spherically-aligned velocity ellipsoid.
+    The projection formulas given below are described in Sec.3 of
+    Cappellari (2020, MNRAS, 494, 4819; hereafter C20)
+    https://ui.adsabs.harvard.edu/abs/2020MNRAS.494.4819C
 
     """
     # TANH rule
@@ -205,7 +208,8 @@ def psf_conv(x, y, inc_deg,
     """
     This routine gives the velocity moment after convolution with a PSF.
     The convolution is done using interpolation of the model on a
-    polar grid, as described in Appendix A of Cappellari (2008, MNRAS, 390, 71).
+    polar grid, as described in Appendix A of Cappellari (2008, MNRAS, 390, 71)
+    https://ui.adsabs.harvard.edu/abs/2008MNRAS.390...71C
 
     """
     # Axisymmetric deprojection of both luminous and total mass.
@@ -356,7 +360,7 @@ class jam_axi_proj:
       `Cappellari (2008) <https://ui.adsabs.harvard.edu/abs/2008MNRAS.390...71C>`_
 
     - The spherically-aligned ``(r, th, phi)`` solution was presented in
-      `Cappellari (2020) <https://ui.adsabs.harvard.edu/abs/10.1093/mnras/staa959>`_
+      `Cappellari (2020) <https://ui.adsabs.harvard.edu/abs/2020MNRAS.494.4819C>`_
 
     Calling Sequence
     ----------------
@@ -385,7 +389,7 @@ class jam_axi_proj:
 
         EXAMPLE: when one obtains the kinematics from optical spectroscopy,
         surf_lum contains the galaxy optical surface brightness, which has
-        typical units of ``Lsun/pc^2`` (solar luminosities per parsec^2).
+        typical units of ``Lsun/pc^2`` (solar luminosities per ``parsec^2``).
     sigma_lum: array_like with shape (n,)
         dispersion (sigma) in arcseconds of the MGE Gaussians describing the
         kinematic-tracer population.
@@ -394,7 +398,7 @@ class jam_axi_proj:
         kinematic-tracer population.
     surf_pot: array_like with shape (m,)
         peak value of the MGE Gaussians describing the galaxy total-mass
-        surface density in units of ``Msun/pc^2`` (solar masses per parsec^2).
+        surface density in units of ``Msun/pc^2`` (solar masses per ``parsec^2``).
         This is the MGE model from which the model gravitational potential is
         computed.
 
@@ -411,7 +415,8 @@ class jam_axi_proj:
         observed axial ratio of the MGE Gaussians describing the galaxy
         total-mass surface density.
     inc: float
-        inclination in degrees (0 being face-on and 90 edge-on).
+        inclination in degrees between the line-of-sight and the galaxy symmetry
+        axis (0 being face-on and 90 edge-on).
     mbh: float
         Mass of a nuclear supermassive black hole in solar masses.
 
@@ -423,7 +428,7 @@ class jam_axi_proj:
         To avoid mistakes, the actual ``mbh`` used by the output model is
         printed on the screen.
     distance: float
-        the distance of the galaxy in Mpc.
+        the distance of the galaxy in ``Mpc``.
     xbin: array_like with shape (p,)
         X coordinates in arcseconds of the bins (or pixels) at which one wants
         to compute the model predictions. The X-axis is assumed to coincide with
@@ -471,9 +476,9 @@ class jam_axi_proj:
         1sigma uncertainty associated to the ``data`` measurements.
 
         EXAMPLE: In the case where the data are given by the
-        ``Vrms = sqrt(velBin^2 + sigBin^2)``, from the error propagation::
+        ``Vrms = np.sqrt(velBin**2 + sigBin**2)``, from the error propagation::
 
-            errors = sqrt((dVel*velBin)^2 + (dSig*sigBin)^2)/RMS,
+            errors = np.sqrt((dVel*velBin)**2 + (dSig*sigBin)**2)/Vrms,
 
         where ``velBin`` and ``sigBin`` are the velocity and dispersion in each
         bin and ``dVel`` and ``dSig`` are the corresponding uncertainties.
@@ -481,8 +486,8 @@ class jam_axi_proj:
     flux_obs: array_like with shape (p,), optional
         Optional mean surface brightness of each bin for plotting.
     goodbins: array_like with shape (p,)
-        Boolean vector with values True for the bins which have to be included
-        in the fit (if requested) and ``chi**2`` calculation.
+        Boolean vector with values ``True`` for the bins which have to be
+        included in the fit (if requested) and ``chi**2`` calculation.
         (Default: fit all bins).
     ml: float, optional
         Mass-to-light ratio (M/L) to multiply the values given by ``surf_pot``.
@@ -521,23 +526,22 @@ class jam_axi_proj:
     plot: bool
         Set this keyword to produce a plot at the end of the calculation.
     quiet: bool
-        Set this keyword to avoid printing values on the screen.
+        Set this keyword to avoid printing values on the console.
     rbh: float, optional
         This scalar gives the sigma in arcsec of the Gaussian representing the
-        central black hole of mass MBH (See Section 3.1.2 of `Cappellari 2008.
-        <http://adsabs.harvard.edu/abs/2008MNRAS.390...71C>`_)
+        central black hole of mass MBH (See Section 3.1.2 of `Cappellari (2008)`_)
         The gravitational potential is indistinguishable from a point source
         for ``radii > 2*rbh``, so the default ``rbh=0.01`` arcsec is appropriate
         in most current situations.
 
-        ``RBH`` should not be decreased unless actually needed!
+        ``rbh`` should not be decreased unless actually needed!
     data: array_like with shape (p,), optional
         observed first or second velocity moment used to fit the model.
 
         EXAMPLE: In the common case where one has only line-of-sight velocities
         the second moment is given by::
 
-            V_RMS = sqrt(velBin**2 + sigBin**2)
+            Vrms = np.sqrt(velBin**2 + sigBin**2)
 
         at the coordinates positions given by the vectors ``xbin`` and ``ybin``.
 
@@ -552,8 +556,8 @@ class jam_axi_proj:
 
         IMPORTANT: PSF convolution is done by creating a 2D image, with pixels
         size given by ``step=max(sigmapsf, pixsize/2)/4``, and convolving it
-        with the PSF + aperture. If the input radii RAD are very large with
-        respect to ``step``, the 2D image may require a too large amount of memory.
+        with the PSF + aperture. If the input radii are very large with respect
+        to ``step``, the 2D image may require a too large amount of memory.
         If this is the case one may compute the model predictions at small radii
         separately from those at large radii, where PSF convolution is not
         needed.
@@ -566,41 +570,43 @@ class jam_axi_proj:
         very cuspy galaxy inside a large aperture, one may want to override the
         default value to force smaller spatial pixels using this keyword.
     moment: {'x', 'y', 'z', 'xx', 'yy', 'zz', 'xy', 'xz', 'yz'}, optional
-        String specifying the component of the velocity first or second moments.
+        String specifying the component of the velocity first or second moments
+        requested by the user in output. All values ar in ``km/s``.
 
-        - ``moment='x'`` gives the first moment <V_x'> of the proper motion in
-          the direction orthogonal to the projected symmetry axis.
+        - ``moment='x'`` gives the first moment ``<V_x'>`` of the proper motion
+          in the direction orthogonal to the projected symmetry axis.
 
-        - ``moment='y'`` gives the first moment <V_y'> of the proper motion in
-          the direction parallel to the projected symmetry axis.
+        - ``moment='y'`` gives the first moment ``<V_y'>`` of the proper motion
+          in the direction parallel to the projected symmetry axis.
 
-        - ``moment='z'`` gives the first moment <V_z'> of the line-of-sight
-          velocity.
+        - ``moment='z'`` gives the first moment ``Vlos = <V_z'>`` of the
+          line-of-sight velocity.
 
-        - ``moment='xx'`` gives sigma_xx=sqrt<V_x'^2> of the component of the
-          proper motion dispersion tensor in the direction orthogonal to the
-          projected symmetry axis.
+        - ``moment='xx'`` gives ``sqrt<V_x'^2>`` of the component of the proper
+          motion dispersion tensor in the direction orthogonal to the projected
+          symmetry axis.
 
-        - ``moment='yy'`` gives sigma_yy=sqrt<V_y'^2> of the component of the
-          proper motion dispersion tensor in the direction parallel to the
-          projected symmetry axis.
+        - ``moment='yy'`` gives ``sqrt<V_y'^2>`` of the component of the proper
+          motion dispersion tensor in the direction parallel to the projected
+          symmetry axis.
 
-        - ``moment='zz'`` (default) gives the usual line-of-sight V_rms=sqrt<V_z'^2>.
+        - ``moment='zz'`` (default) gives the usual line-of-sight
+          ``Vrms = sqrt<V_z'^2>``.
 
-        - ``moment='xy'`` gives the mixed component <V_x'V_y'> of the proper
+        - ``moment='xy'`` gives the mixed component ``<V_x'V_y'>`` of the proper
           motion dispersion tensor.
 
-        - ``moment='xz'`` gives the mixed component <V_x'V_z'> of the proper
+        - ``moment='xz'`` gives the mixed component ``<V_x'V_z'>`` of the proper
           motion dispersion tensor.
 
-        - ``moment='yz'`` gives the mixed component <V_y'V_z'> of the proper
+        - ``moment='yz'`` gives the mixed component ``<V_y'V_z'>`` of the proper
           motion dispersion tensor.
     vmax: float, optional
         Maximum value of the ``data`` to plot.
     vmin: float, optional
         Minimum value of the ``data`` to plot.
     kwargs: dict, optioonal
-        Additional parameters passed to ``plot_velfield``.
+        Additional parameters passed to ``plotbin.plot_velfield``.
 
     Output Parameters
     -----------------
@@ -622,7 +628,7 @@ class jam_axi_proj:
                  / goodbins.sum()
 
     .flux: array_like with shape (p,)
-        PSF-convolved MGE surface brightness of each bin in ``Lsun/pc**2``,
+        PSF-convolved MGE surface brightness of each bin in ``Lsun/pc^2``,
         used to plot the isophotes of the kinematic-tracer on the model results.
 
     ###########################################################################
@@ -717,9 +723,7 @@ class jam_axi_proj:
         sigmaY2 = (sigma_lum*qobs_lum)**2 + sigmapsf[:, None]**2
         surf_conv = surf_lum_pc*qobs_lum*sigma_lum**2*normpsf[:, None]/np.sqrt(sigmaX2*sigmaY2)
         flux = surf_conv[..., None]*np.exp(-0.5*(xbin**2/sigmaX2[..., None] + ybin**2/sigmaY2[..., None]))
-        flux = flux.sum((0, 1))  # PSF-convolved Lsun/pc**2
-
-        chi2 = ml = None
+        flux = flux.sum((0, 1))  # PSF-convolved Lsun/pc^2
 
         if moment in str2[:3]:
 
@@ -727,16 +731,21 @@ class jam_axi_proj:
 
             if data is None:
 
-                if ml is not None:
+                chi2 = None
+                if ml is None:
+                    ml = 1.
+                else:
                     model *= np.sqrt(ml)
 
             else:
 
-                d, m = (data/errors)[goodbins], (model/errors)[goodbins]
                 if (ml is None) or (ml <= 0):
-                    ml = ((d @ m)/(m @ m))**2   # (C08 equation 51)
+                    d, m = (data/errors)[goodbins], (model/errors)[goodbins]
+                    ml = ((d @ m)/(m @ m))**2   # eq. (51) of Cappellari (2008, MNRAS)
+
                 model *= np.sqrt(ml)
-                chi2 = ((d - m*np.sqrt(ml))**2).sum() / goodbins.sum()
+                d, m, e, ok = data, model, errors, goodbins
+                chi2 = np.sum(((d[ok] - m[ok])/e[ok])**2)/ok.sum()
 
                 if not quiet:
                     print(f'inc={inc:.1f} beta={beta[0]:.2f} M/L={ml:.3g} '
