@@ -376,8 +376,10 @@ def vlos(x, y, inc_deg,
         r1 = 0.5*np.log(xCar**2 + (yCar/qmed)**2)  # Log elliptical radius of cartesian grid
         e1 = np.arctan2(np.abs(yCar/qmed), np.abs(xCar)) # Eccentric anomaly of cartesian grid
 
-        wmCar = bilinear_interpolate(logRad, ang, wmPol.reshape(nang, nrad), r1, e1)
+        # Division by mgePol before interpolation reduces interpolation error
         mgeCar = mge_surf(xCar, yCar, surf_lum, sigma_lum, qobs_lum)
+        mgePol = mge_surf(xPol, yPol, surf_lum, sigma_lum, qobs_lum)
+        wm2Car = mgeCar*bilinear_interpolate(logRad, ang, (wmPol/mgePol).reshape(nang, nrad), r1, e1)
 
         if component in ('y', 'z'):
             wmCar *= np.sign(xCar) # Calculation was done in positive quadrant
