@@ -1,7 +1,7 @@
 """
 ##############################################################################
 
-Copyright (C) 2004-2018, Michele Cappellari
+Copyright (C) 2004-2019, Michele Cappellari
 E-mail: michele.cappellari_at_physics.ox.ac.uk
 
 Updated versions of the software are available from my web page
@@ -100,11 +100,11 @@ def ibetam(a, b, x):
     """
     # V1.0: Michele Cappellari, Oxford, 01/APR/2008
     # V2.0: Use Hypergeometric function for negative a or b.
-    #    From equation (6.6.8) of Abramoviz & Stegun (1964)
+    #    From equation (8.17.7) of Olver et al. (2010)
     #    https://dlmf.nist.gov/8.17.E7
     #    MC, Oxford, 04/APR/2008
-    # V3.0: Use recurrence relation of equation (26.5.16)
-    #    from Abramoviz & Stegun (1964) for (a < 0) & (b > 0).
+    # V3.0: Use recurrence relation of equation (8.17.20)
+    #    from Olver et al. (2010) for (a < 0) & (b > 0).
     #    https://dlmf.nist.gov/8.17.E20
     #    After suggestion by Gary Mamon. MC, Oxford, 16/APR/2009
 
@@ -114,7 +114,7 @@ def ibetam(a, b, x):
     else:
         p = int(np.ceil(np.abs(np.min(a))))
         tot = np.zeros((x.size, a.size))
-        for j in range(p):  # Do NOT use gamma recurrence relation to avoid instabilities
+        for j in range(p):  # Do *not* use gamma recurrence relation to avoid instabilities
             tot += special.gamma(j + b + a)/special.gamma(j + 1 + a)*x**(j + a)
         ib = tot*(1 - x)**b/special.gamma(b) + special.betainc(a + p, b, x)
 
@@ -195,11 +195,12 @@ def _second_moment(R, sig_l, sig_m, lum, mass, Mbh, beta, tensor,
         x1 = np.linspace(0.5 - nx, nx - 0.5, 2*nx)*step
         xCar, yCar = np.meshgrid(x1, x1)  # Cartesian grid for convolution
 
-        # Interpolate MGE model and Vrms over cartesian grid
-        #
+        # Interpolate MGE model and Vrms over cartesian grid.
+        # Division by mgePol before interpolation reduces interpolation error
         r = np.sqrt(xCar**2 + yCar**2)
-        wm2Car = np.interp(np.log(r), logRad, wm2Pol)
         mgeCar = (surf_l*np.exp(-0.5*(r[..., None]/sig_l)**2)).sum(-1)
+        mgePol = (surf_l*np.exp(-0.5*(rr[:, None]/sig_l)**2)).sum(-1)
+        wm2Car = mgeCar*np.interp(np.log(r), logRad, wm2Pol/mgePol)
 
         nk = int(np.ceil(mx/step))
         kgrid = np.linspace(-nk, nk, 2*nk + 1)*step
